@@ -299,8 +299,8 @@ module blinkled
   assign _mystream_reduce_is_root = 1;
   reg _mystream_reduce_a_idle;
   reg [33-1:0] _mystream_reduce_a_source_count;
-  reg [4-1:0] _mystream_reduce_a_source_mode;
-  reg [4-1:0] _mystream_reduce_a_source_mode_buf;
+  reg [5-1:0] _mystream_reduce_a_source_mode;
+  reg [16-1:0] _mystream_reduce_a_source_generator_id;
   reg [32-1:0] _mystream_reduce_a_source_offset;
   reg [33-1:0] _mystream_reduce_a_source_size;
   reg [32-1:0] _mystream_reduce_a_source_stride;
@@ -316,8 +316,8 @@ module blinkled
   reg [32-1:0] _mystream_reduce_a_source_empty_data;
   reg [32-1:0] _mystream_reduce_reduce_size_next_parameter_data;
   reg [33-1:0] _mystream_reduce_sum_sink_count;
-  reg [4-1:0] _mystream_reduce_sum_sink_mode;
-  reg [4-1:0] _mystream_reduce_sum_sink_mode_buf;
+  reg [5-1:0] _mystream_reduce_sum_sink_mode;
+  reg [16-1:0] _mystream_reduce_sum_sink_generator_id;
   reg [32-1:0] _mystream_reduce_sum_sink_offset;
   reg [33-1:0] _mystream_reduce_sum_sink_size;
   reg [32-1:0] _mystream_reduce_sum_sink_stride;
@@ -332,8 +332,8 @@ module blinkled
   reg [32-1:0] _mystream_reduce_sum_sink_fifo_wdata;
   reg [32-1:0] _mystream_reduce_sum_sink_immediate;
   reg [33-1:0] _mystream_reduce_sum_valid_sink_count;
-  reg [4-1:0] _mystream_reduce_sum_valid_sink_mode;
-  reg [4-1:0] _mystream_reduce_sum_valid_sink_mode_buf;
+  reg [5-1:0] _mystream_reduce_sum_valid_sink_mode;
+  reg [16-1:0] _mystream_reduce_sum_valid_sink_generator_id;
   reg [32-1:0] _mystream_reduce_sum_valid_sink_offset;
   reg [33-1:0] _mystream_reduce_sum_valid_sink_size;
   reg [32-1:0] _mystream_reduce_sum_valid_sink_stride;
@@ -366,8 +366,8 @@ module blinkled
   assign _mystream_bias_is_root = 1;
   reg _mystream_bias_x_idle;
   reg [33-1:0] _mystream_bias_x_source_count;
-  reg [4-1:0] _mystream_bias_x_source_mode;
-  reg [4-1:0] _mystream_bias_x_source_mode_buf;
+  reg [5-1:0] _mystream_bias_x_source_mode;
+  reg [16-1:0] _mystream_bias_x_source_generator_id;
   reg [32-1:0] _mystream_bias_x_source_offset;
   reg [33-1:0] _mystream_bias_x_source_size;
   reg [32-1:0] _mystream_bias_x_source_stride;
@@ -383,8 +383,8 @@ module blinkled
   reg [32-1:0] _mystream_bias_x_source_empty_data;
   reg _mystream_bias_y_idle;
   reg [33-1:0] _mystream_bias_y_source_count;
-  reg [4-1:0] _mystream_bias_y_source_mode;
-  reg [4-1:0] _mystream_bias_y_source_mode_buf;
+  reg [5-1:0] _mystream_bias_y_source_mode;
+  reg [16-1:0] _mystream_bias_y_source_generator_id;
   reg [32-1:0] _mystream_bias_y_source_offset;
   reg [33-1:0] _mystream_bias_y_source_size;
   reg [32-1:0] _mystream_bias_y_source_stride;
@@ -399,8 +399,8 @@ module blinkled
   wire [32-1:0] _mystream_bias_y_source_fifo_rdata;
   reg [32-1:0] _mystream_bias_y_source_empty_data;
   reg [33-1:0] _mystream_bias_z_sink_count;
-  reg [4-1:0] _mystream_bias_z_sink_mode;
-  reg [4-1:0] _mystream_bias_z_sink_mode_buf;
+  reg [5-1:0] _mystream_bias_z_sink_mode;
+  reg [16-1:0] _mystream_bias_z_sink_generator_id;
   reg [32-1:0] _mystream_bias_z_sink_offset;
   reg [33-1:0] _mystream_bias_z_sink_size;
   reg [32-1:0] _mystream_bias_z_sink_stride;
@@ -1253,7 +1253,7 @@ module blinkled
       _pulse_data_6 <= 1'sd0;
       _pulse_count_6 <= 0;
       _pulse_prev_count_max_6 <= 0;
-      _mystream_reduce_a_source_mode <= 4'b0;
+      _mystream_reduce_a_source_mode <= 5'b0;
       _mystream_reduce_a_source_size <= 0;
       _mystream_reduce_a_source_sel <= 0;
       _mystream_reduce_a_source_size_buf <= 0;
@@ -1273,7 +1273,7 @@ module blinkled
       _tmp_45 <= 0;
       _tmp_46 <= 0;
       _tmp_47 <= 0;
-      _mystream_reduce_sum_sink_mode <= 4'b0;
+      _mystream_reduce_sum_sink_mode <= 5'b0;
       _mystream_reduce_sum_sink_size <= 0;
       _mystream_reduce_sum_sink_sel <= 0;
       _mystream_reduce_sum_sink_size_buf <= 0;
@@ -1384,13 +1384,13 @@ module blinkled
         _pulse_data_6 <= _pulse_current_count_6 >= __delay_data_13__delay_12__delay_11__variable_1 - 1;
       end 
       if(_set_flag_31) begin
-        _mystream_reduce_a_source_mode <= 4'b1000;
+        _mystream_reduce_a_source_mode <= 5'b10000;
         _mystream_reduce_a_source_size <= _th_comp_read_size_0;
       end 
       if(_set_flag_31) begin
         _mystream_reduce_a_source_sel <= 1;
       end 
-      if(_mystream_reduce_source_start && _mystream_reduce_a_source_mode & 4'b1000 && _mystream_reduce_stream_oready) begin
+      if(_mystream_reduce_source_start && _mystream_reduce_a_source_mode & 5'b10000 && _mystream_reduce_stream_oready) begin
         _mystream_reduce_a_idle <= 0;
         _mystream_reduce_a_source_size_buf <= _mystream_reduce_a_source_size;
       end 
@@ -1456,13 +1456,13 @@ module blinkled
         _tmp_47 <= _tmp_46;
       end 
       if(_tmp_41) begin
-        _mystream_reduce_sum_sink_mode <= 4'b1000;
+        _mystream_reduce_sum_sink_mode <= 5'b10000;
         _mystream_reduce_sum_sink_size <= _tmp_47;
       end 
       if(_tmp_41) begin
         _mystream_reduce_sum_sink_sel <= 2;
       end 
-      if(_mystream_reduce_sink_start && _mystream_reduce_sum_sink_mode & 4'b1000 && _mystream_reduce_stream_oready) begin
+      if(_mystream_reduce_sink_start && _mystream_reduce_sum_sink_mode & 5'b10000 && _mystream_reduce_stream_oready) begin
         _mystream_reduce_sum_sink_size_buf <= _mystream_reduce_sum_sink_size;
       end 
       if((_mystream_reduce_sum_sink_fsm_1 == 1) && _mystream_reduce_stream_oready) begin
@@ -1656,13 +1656,13 @@ module blinkled
       _mystream_bias_z_sink_fifo_enq <= 0;
       __mystream_bias_stream_ivalid_1 <= 0;
       _plus_data_10 <= 0;
-      _mystream_bias_x_source_mode <= 4'b0;
+      _mystream_bias_x_source_mode <= 5'b0;
       _mystream_bias_x_source_size <= 0;
       _mystream_bias_x_source_sel <= 0;
       _mystream_bias_x_source_size_buf <= 0;
       __variable_wdata_8 <= 0;
       _mystream_bias_x_source_count <= 0;
-      _mystream_bias_y_source_mode <= 4'b0;
+      _mystream_bias_y_source_mode <= 5'b0;
       _mystream_bias_y_source_offset <= 0;
       _mystream_bias_y_source_size <= 0;
       _mystream_bias_y_source_stride <= 0;
@@ -1679,7 +1679,7 @@ module blinkled
       _tmp_60 <= 0;
       _tmp_61 <= 0;
       _tmp_62 <= 0;
-      _mystream_bias_z_sink_mode <= 4'b0;
+      _mystream_bias_z_sink_mode <= 5'b0;
       _mystream_bias_z_sink_size <= 0;
       _mystream_bias_z_sink_sel <= 0;
       _mystream_bias_z_sink_size_buf <= 0;
@@ -1722,13 +1722,13 @@ module blinkled
         _plus_data_10 <= mystream_bias_x_data + mystream_bias_y_data;
       end 
       if(_set_flag_50) begin
-        _mystream_bias_x_source_mode <= 4'b1000;
+        _mystream_bias_x_source_mode <= 5'b10000;
         _mystream_bias_x_source_size <= _th_comp_write_size_1;
       end 
       if(_set_flag_50) begin
         _mystream_bias_x_source_sel <= 1;
       end 
-      if(_mystream_bias_source_start && _mystream_bias_x_source_mode & 4'b1000 && _mystream_bias_stream_oready) begin
+      if(_mystream_bias_source_start && _mystream_bias_x_source_mode & 5'b10000 && _mystream_bias_stream_oready) begin
         _mystream_bias_x_idle <= 0;
         _mystream_bias_x_source_size_buf <= _mystream_bias_x_source_size;
       end 
@@ -1752,7 +1752,7 @@ module blinkled
         _mystream_bias_x_idle <= 1;
       end 
       if(_set_flag_53) begin
-        _mystream_bias_y_source_mode <= 4'b1;
+        _mystream_bias_y_source_mode <= 5'b1;
         _mystream_bias_y_source_offset <= 0;
         _mystream_bias_y_source_size <= _th_comp_write_size_1;
         _mystream_bias_y_source_stride <= 1;
@@ -1760,7 +1760,7 @@ module blinkled
       if(_set_flag_53) begin
         _mystream_bias_y_source_sel <= 2;
       end 
-      if(_mystream_bias_source_start && _mystream_bias_y_source_mode & 4'b1 && _mystream_bias_stream_oready) begin
+      if(_mystream_bias_source_start && _mystream_bias_y_source_mode & 5'b1 && _mystream_bias_stream_oready) begin
         _mystream_bias_y_source_offset_buf <= _mystream_bias_y_source_offset;
         _mystream_bias_y_source_size_buf <= _mystream_bias_y_source_size;
         _mystream_bias_y_source_stride_buf <= _mystream_bias_y_source_stride;
@@ -1806,13 +1806,13 @@ module blinkled
         _tmp_62 <= _tmp_61;
       end 
       if(_tmp_59) begin
-        _mystream_bias_z_sink_mode <= 4'b1000;
+        _mystream_bias_z_sink_mode <= 5'b10000;
         _mystream_bias_z_sink_size <= _tmp_62;
       end 
       if(_tmp_59) begin
         _mystream_bias_z_sink_sel <= 3;
       end 
-      if(_mystream_bias_sink_start && _mystream_bias_z_sink_mode & 4'b1000 && _mystream_bias_stream_oready) begin
+      if(_mystream_bias_sink_start && _mystream_bias_z_sink_mode & 5'b10000 && _mystream_bias_stream_oready) begin
         _mystream_bias_z_sink_size_buf <= _mystream_bias_z_sink_size;
       end 
       if((_mystream_bias_z_sink_fsm_2 == 1) && _mystream_bias_stream_oready) begin
@@ -2382,7 +2382,7 @@ module blinkled
     end else begin
       case(_mystream_reduce_a_source_fsm_0)
         _mystream_reduce_a_source_fsm_0_init: begin
-          if(_mystream_reduce_source_start && _mystream_reduce_a_source_mode & 4'b1000 && _mystream_reduce_stream_oready) begin
+          if(_mystream_reduce_source_start && _mystream_reduce_a_source_mode & 5'b10000 && _mystream_reduce_stream_oready) begin
             _mystream_reduce_a_source_fsm_0 <= _mystream_reduce_a_source_fsm_0_1;
           end 
         end
@@ -2412,7 +2412,7 @@ module blinkled
     end else begin
       case(_mystream_reduce_sum_sink_fsm_1)
         _mystream_reduce_sum_sink_fsm_1_init: begin
-          if(_mystream_reduce_sink_start && _mystream_reduce_sum_sink_mode & 4'b1000 && _mystream_reduce_stream_oready) begin
+          if(_mystream_reduce_sink_start && _mystream_reduce_sum_sink_mode & 5'b10000 && _mystream_reduce_stream_oready) begin
             _mystream_reduce_sum_sink_fsm_1 <= _mystream_reduce_sum_sink_fsm_1_1;
           end 
         end
@@ -2442,7 +2442,7 @@ module blinkled
     end else begin
       case(_mystream_bias_x_source_fsm_0)
         _mystream_bias_x_source_fsm_0_init: begin
-          if(_mystream_bias_source_start && _mystream_bias_x_source_mode & 4'b1000 && _mystream_bias_stream_oready) begin
+          if(_mystream_bias_source_start && _mystream_bias_x_source_mode & 5'b10000 && _mystream_bias_stream_oready) begin
             _mystream_bias_x_source_fsm_0 <= _mystream_bias_x_source_fsm_0_1;
           end 
         end
@@ -2472,7 +2472,7 @@ module blinkled
     end else begin
       case(_mystream_bias_y_source_fsm_1)
         _mystream_bias_y_source_fsm_1_init: begin
-          if(_mystream_bias_source_start && _mystream_bias_y_source_mode & 4'b1 && _mystream_bias_stream_oready) begin
+          if(_mystream_bias_source_start && _mystream_bias_y_source_mode & 5'b1 && _mystream_bias_stream_oready) begin
             _mystream_bias_y_source_fsm_1 <= _mystream_bias_y_source_fsm_1_1;
           end 
         end
@@ -2502,7 +2502,7 @@ module blinkled
     end else begin
       case(_mystream_bias_z_sink_fsm_2)
         _mystream_bias_z_sink_fsm_2_init: begin
-          if(_mystream_bias_sink_start && _mystream_bias_z_sink_mode & 4'b1000 && _mystream_bias_stream_oready) begin
+          if(_mystream_bias_sink_start && _mystream_bias_z_sink_mode & 5'b10000 && _mystream_bias_stream_oready) begin
             _mystream_bias_z_sink_fsm_2 <= _mystream_bias_z_sink_fsm_2_1;
           end 
         end
