@@ -209,8 +209,8 @@ module blinkled
   assign _mystream_is_root = 1;
   reg _mystream_a_idle;
   reg [33-1:0] _mystream_a_source_count;
-  reg [4-1:0] _mystream_a_source_mode;
-  reg [4-1:0] _mystream_a_source_mode_buf;
+  reg [5-1:0] _mystream_a_source_mode;
+  reg [16-1:0] _mystream_a_source_generator_id;
   reg [32-1:0] _mystream_a_source_offset;
   reg [33-1:0] _mystream_a_source_size;
   reg [32-1:0] _mystream_a_source_stride;
@@ -226,8 +226,8 @@ module blinkled
   reg [32-1:0] _mystream_a_source_empty_data;
   reg _mystream_b_idle;
   reg [33-1:0] _mystream_b_source_count;
-  reg [4-1:0] _mystream_b_source_mode;
-  reg [4-1:0] _mystream_b_source_mode_buf;
+  reg [5-1:0] _mystream_b_source_mode;
+  reg [16-1:0] _mystream_b_source_generator_id;
   reg [32-1:0] _mystream_b_source_offset;
   reg [33-1:0] _mystream_b_source_size;
   reg [32-1:0] _mystream_b_source_stride;
@@ -242,8 +242,8 @@ module blinkled
   wire [32-1:0] _mystream_b_source_fifo_rdata;
   reg [32-1:0] _mystream_b_source_empty_data;
   reg [33-1:0] _mystream_c_sink_count;
-  reg [4-1:0] _mystream_c_sink_mode;
-  reg [4-1:0] _mystream_c_sink_mode_buf;
+  reg [5-1:0] _mystream_c_sink_mode;
+  reg [16-1:0] _mystream_c_sink_generator_id;
   reg [32-1:0] _mystream_c_sink_offset;
   reg [33-1:0] _mystream_c_sink_size;
   reg [32-1:0] _mystream_c_sink_stride;
@@ -873,7 +873,7 @@ module blinkled
       _mystream_c_sink_fifo_enq <= 0;
       __mystream_stream_ivalid_1 <= 0;
       _plus_data_2 <= 0;
-      _mystream_a_source_mode <= 4'b0;
+      _mystream_a_source_mode <= 5'b0;
       _mystream_a_source_offset <= 0;
       _mystream_a_source_size <= 0;
       _mystream_a_source_stride <= 0;
@@ -884,7 +884,7 @@ module blinkled
       __variable_wdata_0 <= 0;
       _mystream_a_source_ram_raddr <= 0;
       _mystream_a_source_count <= 0;
-      _mystream_b_source_mode <= 4'b0;
+      _mystream_b_source_mode <= 5'b0;
       _mystream_b_source_offset <= 0;
       _mystream_b_source_size <= 0;
       _mystream_b_source_stride <= 0;
@@ -904,7 +904,7 @@ module blinkled
       _tmp_40 <= 0;
       _tmp_41 <= 0;
       _tmp_42 <= 0;
-      _mystream_c_sink_mode <= 4'b0;
+      _mystream_c_sink_mode <= 5'b0;
       _mystream_c_sink_offset <= 0;
       _mystream_c_sink_size <= 0;
       _mystream_c_sink_stride <= 0;
@@ -952,7 +952,7 @@ module blinkled
         _plus_data_2 <= mystream_a_data + mystream_b_data;
       end 
       if(_set_flag_27) begin
-        _mystream_a_source_mode <= 4'b1;
+        _mystream_a_source_mode <= 5'b1;
         _mystream_a_source_offset <= _th_comp_offset_3;
         _mystream_a_source_size <= _th_comp_size_2;
         _mystream_a_source_stride <= 1;
@@ -960,7 +960,7 @@ module blinkled
       if(_set_flag_27) begin
         _mystream_a_source_sel <= 1;
       end 
-      if(_mystream_source_start && _mystream_a_source_mode & 4'b1 && _mystream_stream_oready) begin
+      if(_mystream_source_start && _mystream_a_source_mode & 5'b1 && _mystream_stream_oready) begin
         _mystream_a_source_offset_buf <= _mystream_a_source_offset;
         _mystream_a_source_size_buf <= _mystream_a_source_size;
         _mystream_a_source_stride_buf <= _mystream_a_source_stride;
@@ -988,7 +988,7 @@ module blinkled
         _mystream_a_idle <= 1;
       end 
       if(_set_flag_30) begin
-        _mystream_b_source_mode <= 4'b1;
+        _mystream_b_source_mode <= 5'b1;
         _mystream_b_source_offset <= _th_comp_offset_3;
         _mystream_b_source_size <= _th_comp_size_2;
         _mystream_b_source_stride <= 1;
@@ -996,7 +996,7 @@ module blinkled
       if(_set_flag_30) begin
         _mystream_b_source_sel <= 2;
       end 
-      if(_mystream_source_start && _mystream_b_source_mode & 4'b1 && _mystream_stream_oready) begin
+      if(_mystream_source_start && _mystream_b_source_mode & 5'b1 && _mystream_stream_oready) begin
         _mystream_b_source_offset_buf <= _mystream_b_source_offset;
         _mystream_b_source_size_buf <= _mystream_b_source_size;
         _mystream_b_source_stride_buf <= _mystream_b_source_stride;
@@ -1051,7 +1051,7 @@ module blinkled
         _tmp_42 <= _tmp_41;
       end 
       if(_tmp_36) begin
-        _mystream_c_sink_mode <= 4'b1;
+        _mystream_c_sink_mode <= 5'b1;
         _mystream_c_sink_offset <= _tmp_39;
         _mystream_c_sink_size <= _tmp_42;
         _mystream_c_sink_stride <= 1;
@@ -1059,7 +1059,7 @@ module blinkled
       if(_tmp_36) begin
         _mystream_c_sink_sel <= 3;
       end 
-      if(_mystream_sink_start && _mystream_c_sink_mode & 4'b1 && _mystream_stream_oready) begin
+      if(_mystream_sink_start && _mystream_c_sink_mode & 5'b1 && _mystream_stream_oready) begin
         _mystream_c_sink_offset_buf <= _mystream_c_sink_offset;
         _mystream_c_sink_size_buf <= _mystream_c_sink_size;
         _mystream_c_sink_stride_buf <= _mystream_c_sink_stride;
@@ -1520,7 +1520,7 @@ module blinkled
     end else begin
       case(_mystream_a_source_fsm_0)
         _mystream_a_source_fsm_0_init: begin
-          if(_mystream_source_start && _mystream_a_source_mode & 4'b1 && _mystream_stream_oready) begin
+          if(_mystream_source_start && _mystream_a_source_mode & 5'b1 && _mystream_stream_oready) begin
             _mystream_a_source_fsm_0 <= _mystream_a_source_fsm_0_1;
           end 
         end
@@ -1550,7 +1550,7 @@ module blinkled
     end else begin
       case(_mystream_b_source_fsm_1)
         _mystream_b_source_fsm_1_init: begin
-          if(_mystream_source_start && _mystream_b_source_mode & 4'b1 && _mystream_stream_oready) begin
+          if(_mystream_source_start && _mystream_b_source_mode & 5'b1 && _mystream_stream_oready) begin
             _mystream_b_source_fsm_1 <= _mystream_b_source_fsm_1_1;
           end 
         end
@@ -1580,7 +1580,7 @@ module blinkled
     end else begin
       case(_mystream_c_sink_fsm_2)
         _mystream_c_sink_fsm_2_init: begin
-          if(_mystream_sink_start && _mystream_c_sink_mode & 4'b1 && _mystream_stream_oready) begin
+          if(_mystream_sink_start && _mystream_c_sink_mode & 5'b1 && _mystream_stream_oready) begin
             _mystream_c_sink_fsm_2 <= _mystream_c_sink_fsm_2_1;
           end 
         end
