@@ -94,7 +94,7 @@ module test;
   assign _axi_arprot = 0;
   assign _axi_arqos = 0;
   assign _axi_aruser = 0;
-  reg [32-1:0] outstanding_wreq_count_0;
+  reg [3-1:0] outstanding_wcount_0;
   assign _axi_rready = 0;
   wire [32-1:0] _tmp_1;
   assign _tmp_1 = _axi_awaddr;
@@ -363,7 +363,7 @@ module test;
     _axi_araddr = 0;
     _axi_arlen = 0;
     _axi_arvalid = 0;
-    outstanding_wreq_count_0 = 0;
+    outstanding_wcount_0 = 0;
     fsm = fsm_init;
     counter_27 = 0;
     __axi_cond_0_1 = 0;
@@ -385,7 +385,7 @@ module test;
 
   always @(posedge CLK) begin
     if(RST) begin
-      outstanding_wreq_count_0 <= 0;
+      outstanding_wcount_0 <= 0;
       _axi_araddr <= 0;
       _axi_arlen <= 0;
       _axi_arvalid <= 0;
@@ -421,11 +421,11 @@ module test;
         _axi_wlast <= 0;
         last_30 <= 0;
       end 
-      if(_axi_awvalid && _axi_awready && !(_axi_bvalid && _axi_bready)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 + 1;
+      if(_axi_wlast && _axi_wvalid && _axi_wready && !(_axi_bvalid && _axi_bready) && (outstanding_wcount_0 < 7)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 + 1;
       end 
-      if(!(_axi_awvalid && _axi_awready) && (_axi_bvalid && _axi_bready) && (outstanding_wreq_count_0 > 0)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 - 1;
+      if(!(_axi_wlast && _axi_wvalid && _axi_wready) && (_axi_bvalid && _axi_bready) && (outstanding_wcount_0 > 0)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 - 1;
       end 
       _axi_araddr <= 0;
       _axi_arlen <= 0;
@@ -443,14 +443,14 @@ module test;
       if(_axi_awvalid && !_axi_awready) begin
         _axi_awvalid <= _axi_awvalid;
       end 
-      if((fsm == 1) && ((counter_27 > 0) && (_axi_wready || !_axi_wvalid) && (counter_27 > 0))) begin
+      if((fsm == 1) && ((counter_27 > 0) && (outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid) && (counter_27 > 0))) begin
         _axi_wdata <= wdata;
         _axi_wvalid <= 1;
         _axi_wlast <= 0;
         _axi_wstrb <= { 4{ 1'd1 } };
         counter_27 <= counter_27 - 1;
       end 
-      if((fsm == 1) && ((counter_27 > 0) && (_axi_wready || !_axi_wvalid) && (counter_27 > 0)) && (counter_27 == 1)) begin
+      if((fsm == 1) && ((counter_27 > 0) && (outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid) && (counter_27 > 0)) && (counter_27 == 1)) begin
         _axi_wlast <= 1;
         last_28 <= 1;
       end 
@@ -473,14 +473,14 @@ module test;
       if(_axi_awvalid && !_axi_awready) begin
         _axi_awvalid <= _axi_awvalid;
       end 
-      if((fsm == 3) && ((counter_29 > 0) && (_axi_wready || !_axi_wvalid) && (counter_29 > 0))) begin
+      if((fsm == 3) && ((counter_29 > 0) && (outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid) && (counter_29 > 0))) begin
         _axi_wdata <= wdata;
         _axi_wvalid <= 1;
         _axi_wlast <= 0;
         _axi_wstrb <= { 4{ 1'd1 } };
         counter_29 <= counter_29 - 1;
       end 
-      if((fsm == 3) && ((counter_29 > 0) && (_axi_wready || !_axi_wvalid) && (counter_29 > 0)) && (counter_29 == 1)) begin
+      if((fsm == 3) && ((counter_29 > 0) && (outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid) && (counter_29 > 0)) && (counter_29 == 1)) begin
         _axi_wlast <= 1;
         last_30 <= 1;
       end 
@@ -511,7 +511,7 @@ module test;
           end 
         end
         fsm_1: begin
-          if((counter_27 > 0) && (_axi_wready || !_axi_wvalid)) begin
+          if((counter_27 > 0) && (outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid)) begin
             wdata <= wdata + 1;
           end 
           if(last_28) begin
@@ -524,7 +524,7 @@ module test;
           end 
         end
         fsm_3: begin
-          if((counter_29 > 0) && (_axi_wready || !_axi_wvalid)) begin
+          if((counter_29 > 0) && (outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid)) begin
             wdata <= wdata + 1;
           end 
           if(last_30) begin
