@@ -89,7 +89,7 @@ def mkTest(memimg_name=None):
                      params=m.connect_params(main),
                      ports=m.connect_ports(main))
 
-    simulation.setup_waveform(m, uut, m.get_vars())
+    # simulation.setup_waveform(m, uut, m.get_vars())
     simulation.setup_clock(m, clk, hperiod=5)
     init = simulation.setup_reset(m, rst, m.make_reset(), period=100)
 
