@@ -309,15 +309,15 @@ class Stream(object):
         for var in sorted(all_vars, key=lambda x: (-1, x.object_id)
                           if x.start_stage is None else
                           (x.start_stage, x.object_id)):
-            bit_length = var.sig_data.bit_length()
-            if bit_length is None:
-                bit_length = 1
-            if bit_length <= 0:
-                bit_length = 1
+            bitwidth = vtypes.get_width(var.sig_data)
+            if bitwidth is None:
+                bitwidth = 1
+            if bitwidth <= 0:
+                bitwidth = 1
 
             base = (var.dump_base if hasattr(var, 'dump_base') else
                     self.dump_base)
-            total_length = int(math.ceil(bit_length / math.log(base, 2)))
+            total_length = int(math.ceil(bitwidth / math.log(base, 2)))
             #point_length = int(math.ceil(var.point / math.log(base, 2)))
             #point_length = max(point_length, 8)
             #longest_var_len = max(longest_var_len, total_length, point_length)
@@ -553,29 +553,27 @@ class Stream(object):
         self.valid_list = None
 
         if self.ivalid is None and self.oready is None:
+            self.senable = None
             if self.ovalid is not None:
                 self.ovalid.assign(1)
             if self.iready is not None:
                 self.iready.assign(1)
-            self.senable = None
-            return
-
-        if self.oready is None:
-            self._make_valid_chain(seq)
-            self.senable = None
             return
 
         if self.ivalid is None:
-            self.iready.assign(self.oready)
             self.senable = self.oready
+            if self.iready is not None:
+                self.iready.assign(self.senable)
             return
 
-        cond = vtypes.OrList(vtypes.Not(self.ovalid), self.oready)
-        self.senable = self.module.TmpWire()
-        self.senable.assign(cond)
+        if self.oready is None:
+            self.senable = None
+        else:
+            self.senable = self.oready
 
         self._make_valid_chain(seq, self.senable)
-        self.iready.assign(self.senable)
+        if self.iready is not None:
+            self.iready.assign(self.senable)
 
     def _make_valid_chain(self, seq, cond=None):
         self.valid_list = []
@@ -585,7 +583,7 @@ class Stream(object):
         prev = self.ivalid
 
         for i in range(self.max_stage):
-            v = self.module.Reg("_{}_{}".format(name, i), initval=0)
+            v = self.module.Reg("_{}_{}".format(name, i + 1), initval=0)
             self.valid_list.append(v)
             seq(v(prev), cond=cond)
             prev = v
@@ -638,7 +636,7 @@ class Stream(object):
     # -------------------------------------------------------------------------
     def __getattr__(self, attr):
         try:
-            return object.__getattr__(self, attr)
+            return object.__getattribute__(self, attr)
 
         except AttributeError as e:
             if attr.startswith('__') or attr not in dir(stypes):
